@@ -21,7 +21,7 @@ namespace SourceGit.Commands
 
         public Diff(string repo, Models.DiffOption opt, int unified, bool ignoreWhitespace)
         {
-            _result.TextDiff = new Models.TextDiff() { Option = opt };
+            _result.TextDiff = new Models.TextDiff();
 
             WorkingDirectory = repo;
             Context = repo;
@@ -252,10 +252,10 @@ namespace SourceGit.Commands
                         foreach (var chunk in chunks)
                         {
                             if (chunk.DeletedCount > 0)
-                                left.Highlights.Add(new Models.TextInlineRange(chunk.DeletedStart, chunk.DeletedCount));
+                                left.Highlights.Add(new Models.TextRange(chunk.DeletedStart, chunk.DeletedCount));
 
                             if (chunk.AddedCount > 0)
-                                right.Highlights.Add(new Models.TextInlineRange(chunk.AddedStart, chunk.AddedCount));
+                                right.Highlights.Add(new Models.TextRange(chunk.AddedStart, chunk.AddedCount));
                         }
                     }
                 }
