@@ -1,4 +1,5 @@
-﻿using System.Threading.Tasks;
+﻿using System.Text;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
@@ -6,26 +7,24 @@ namespace SourceGit.Commands
     {
         public Fetch(string repo, string remote, bool noTags, bool force)
         {
-            _remoteKey = $"remote.{remote}.sshkey";
+            _remote = remote;
 
             WorkingDirectory = repo;
             Context = repo;
-            Args = "fetch --progress --verbose ";
-
-            if (noTags)
-                Args += "--no-tags ";
-            else
-                Args += "--tags ";
 
+            var builder = new StringBuilder(512);
+            builder.Append("fetch --progress --verbose ");
+            builder.Append(noTags ? "--no-tags " : "--tags ");
             if (force)
-                Args += "--force ";
+                builder.Append("--force ");
+            builder.Append(remote);
 
-            Args += remote;
+            Args = builder.ToString();
         }
 
         public Fetch(string repo, Models.Branch local, Models.Branch remote)
         {
-            _remoteKey = $"remote.{remote.Remote}.sshkey";
+            _remote = remote.Remote;
 
             WorkingDirectory = repo;
             Context = repo;
@@ -34,10 +33,10 @@ namespace SourceGit.Commands
 
         public async Task<bool> RunAsync()
         {
-            SSHKey = await new Config(WorkingDirectory).GetAsync(_remoteKey).ConfigureAwait(false);
+            SSHKey = await new Config(WorkingDirectory).GetAsync($"remote.{_remote}.sshkey").ConfigureAwait(false);
             return await ExecAsync().ConfigureAwait(false);
         }
 
-        private readonly string _remoteKey;
+        private readonly string _remote;
     }
 }
