@@ -1,6 +1,7 @@
 ﻿using System;
 using System.IO;
 using System.Text.RegularExpressions;
+using System.Web;
 
 namespace SourceGit.Models
 {
@@ -65,7 +66,6 @@ namespace SourceGit.Models
 
             if (URL.StartsWith("http", StringComparison.Ordinal))
             {
-                // Try to remove the user before host and `.git` extension.
                 var uri = new Uri(URL.EndsWith(".git", StringComparison.Ordinal) ? URL.Substring(0, URL.Length - 4) : URL);
                 if (uri.Port != 80 && uri.Port != 443)
                     url = $"{uri.Scheme}://{uri.Host}:{uri.Port}{uri.LocalPath}";
@@ -84,5 +84,56 @@ namespace SourceGit.Models
 
             return false;
         }
+
+        public bool TryGetCreatePullRequestURL(out string url, string mergeBranch)
+        {
+            url = null;
+
+            if (!TryGetVisitURL(out var baseURL))
+                return false;
+
+            var uri = new Uri(baseURL);
+            var host = uri.Host;
+            var route = uri.AbsolutePath.TrimStart('/');
+            var encodedBranch = HttpUtility.UrlEncode(mergeBranch);
+
+            if (host.Contains("github.com", StringComparison.Ordinal))
+            {
+                url = $"{baseURL}/compare/{encodedBranch}?expand=1";
+                return true;
+            }
+
+            if (host.Contains("gitlab", StringComparison.Ordinal))
+            {
+                url = $"{baseURL}/-/merge_requests/new?merge_request%5Bsource_branch%5D={encodedBranch}";
+                return true;
+            }
+
+            if (host.Equals("gitee.com", StringComparison.Ordinal))
+            {
+                url = $"{baseURL}/pulls/new?source={encodedBranch}";
+                return true;
+            }
+
+            if (host.Equals("bitbucket.org", StringComparison.Ordinal))
+            {
+                url = $"{baseURL}/pull-requests/new?source={encodedBranch}";
+                return true;
+            }
+
+            if (host.Equals("gitea.org", StringComparison.Ordinal))
+            {
+                url = $"{baseURL}/compare/{encodedBranch}";
+                return true;
+            }
+
+            if (host.Contains("azure.com", StringComparison.Ordinal))
+            {
+                url = $"{baseURL}/pullrequestcreate?sourceRef={encodedBranch}";
+                return true;
+            }
+
+            return false;
+        }
     }
 }
