@@ -10,9 +10,9 @@ namespace SourceGit.ViewModels
     {
         public bool HasValidUserName
         {
-            get;
-            private set;
-        } = false;
+            get => _hasValidUsername;
+            private set => SetProperty(ref _hasValidUsername, value);
+        }
 
         public bool IsLoading
         {
@@ -62,7 +62,7 @@ namespace SourceGit.ViewModels
 
             IsLoading = true;
 
-            var succ = await _repo.UnlockLFSFileAsync(_remote, lfsLock.File, force, false);
+            var succ = await _repo.UnlockLFSFileAsync(_remote, lfsLock.Path, force, false);
             if (succ)
             {
                 _cachedLocks.Remove(lfsLock);
@@ -72,6 +72,35 @@ namespace SourceGit.ViewModels
             IsLoading = false;
         }
 
+        public async Task UnlockAllMyLocksAsync()
+        {
+            if (_isLoading || string.IsNullOrEmpty(_userName))
+                return;
+
+            var locks = new List<string>();
+            foreach (var lfsLock in _cachedLocks)
+            {
+                if (lfsLock.Owner.Name.Equals(_userName, StringComparison.Ordinal))
+                    locks.Add(lfsLock.Path);
+            }
+
+            if (locks.Count == 0)
+                return;
+
+            IsLoading = true;
+
+            var log = _repo.CreateLog("Unlock LFS Locks");
+            var succ = await new Commands.LFS(_repo.FullPath).Use(log).UnlockMultipleAsync(_remote, locks, true);
+            if (succ)
+            {
+                _cachedLocks.RemoveAll(lfsLock => lfsLock.Owner.Name.Equals(_userName, StringComparison.Ordinal));
+                UpdateVisibleLocks();
+            }
+
+            log.Complete();
+            IsLoading = false;
+        }
+
         private void UpdateVisibleLocks()
         {
             var visible = new List<Models.LFSLock>();
@@ -84,7 +113,7 @@ namespace SourceGit.ViewModels
             {
                 foreach (var lfsLock in _cachedLocks)
                 {
-                    if (lfsLock.User.Equals(_userName, StringComparison.Ordinal))
+                    if (lfsLock.Owner.Name.Equals(_userName, StringComparison.Ordinal))
                         visible.Add(lfsLock);
                 }
             }
@@ -99,5 +128,6 @@ namespace SourceGit.ViewModels
         private List<Models.LFSLock> _visibleLocks = [];
         private bool _showOnlyMyLocks = false;
         private string _userName;
+        private bool _hasValidUsername;
     }
 }
