@@ -41,12 +41,6 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _repositorySidebarWidth, value);
         }
 
-        public GridLength HistoriesAuthorColumnWidth
-        {
-            get => _historiesAuthorColumnWidth;
-            set => SetProperty(ref _historiesAuthorColumnWidth, value);
-        }
-
         public GridLength WorkingCopyLeftWidth
         {
             get => _workingCopyLeftWidth;
@@ -71,11 +65,17 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _commitDetailFilesLeftWidth, value);
         }
 
+        public DataGridLength AuthorColumnWidth
+        {
+            get => _authorColumnWidth;
+            set => SetProperty(ref _authorColumnWidth, value);
+        }
+
         private GridLength _repositorySidebarWidth = new GridLength(250, GridUnitType.Pixel);
-        private GridLength _historiesAuthorColumnWidth = new GridLength(120, GridUnitType.Pixel);
         private GridLength _workingCopyLeftWidth = new GridLength(300, GridUnitType.Pixel);
         private GridLength _stashesLeftWidth = new GridLength(300, GridUnitType.Pixel);
         private GridLength _commitDetailChangesLeftWidth = new GridLength(256, GridUnitType.Pixel);
         private GridLength _commitDetailFilesLeftWidth = new GridLength(256, GridUnitType.Pixel);
+        private DataGridLength _authorColumnWidth = new DataGridLength(120, DataGridLengthUnitType.Pixel, 120, 120);
     }
 }
