@@ -7,13 +7,14 @@ namespace SourceGit.Views
     {
         public AssumeUnchangedManager()
         {
+            CloseOnESC = true;
             InitializeComponent();
         }
 
-        private void OnRemoveButtonClicked(object sender, RoutedEventArgs e)
+        private async void OnRemoveButtonClicked(object sender, RoutedEventArgs e)
         {
             if (DataContext is ViewModels.AssumeUnchangedManager vm && sender is Button button)
-                vm.Remove(button.DataContext as string);
+                await vm.RemoveAsync(button.DataContext as string);
 
             e.Handled = true;
         }
