@@ -1,16 +1,9 @@
-using System;
 using Avalonia.Interactivity;
 
 namespace SourceGit.Views
 {
     public partial class Confirm : ChromelessWindow
     {
-        public Action OnSure
-        {
-            get;
-            set;
-        }
-
         public Confirm()
         {
             InitializeComponent();
@@ -18,7 +11,6 @@ namespace SourceGit.Views
 
         private void Sure(object _1, RoutedEventArgs _2)
         {
-            OnSure?.Invoke();
             Close(true);
         }
 
